@@ -665,26 +665,31 @@ zeitgeist_event_new_from_variant (GVariant *event)
   /* Parse event data */
   if (g_variant_iter_n_children (event_data) < 5)
     {
-      g_critical ("Event data truncated at length %d",
+      g_critical ("Event data truncated at length %lu",
                   g_variant_iter_n_children (event_data));
       goto cleanup;
     }
 
   // FIXME: Use g_variant_get_string() to cause less reallocations
-  g_variant_iter_loop (event_data, "s", &str);
+  g_variant_iter_next (event_data, "s", &str);
   zeitgeist_event_set_id (result, g_ascii_strtoull (str, NULL, 0));
+  g_free (str);
 
-  g_variant_iter_loop (event_data, "s", &str);
+  g_variant_iter_next (event_data, "s", &str);
   zeitgeist_event_set_timestamp (result,  g_ascii_strtoll (str, NULL, 0));
+  g_free (str);
 
-  g_variant_iter_loop (event_data, "s", &str);
+  g_variant_iter_next (event_data, "s", &str);
   zeitgeist_event_set_interpretation (result,  str[0] == '\0' ? NULL : str);
+  g_free (str);
 
-  g_variant_iter_loop (event_data, "s", &str);
+  g_variant_iter_next (event_data, "s", &str);
   zeitgeist_event_set_manifestation (result,  str[0] == '\0' ? NULL : str);
+  g_free (str);
 
-  g_variant_iter_loop (event_data, "s", &str);
+  g_variant_iter_next (event_data, "s", &str);
   zeitgeist_event_set_actor (result,  str[0] == '\0' ? NULL : str);
+  g_free (str);
 
   /* Build the list of subjects */
   while (g_variant_iter_loop (subjects, "as", &subject_data))
@@ -692,33 +697,40 @@ zeitgeist_event_new_from_variant (GVariant *event)
     /* Parse subject data */
     if (g_variant_iter_n_children (subject_data) < 7)
       {
-        g_critical ("Subject data truncated at length %d",
+        g_critical ("Subject data truncated at length %lu",
                     g_variant_iter_n_children (subject_data));
         goto cleanup;
       }
 
     subject = g_object_new (ZEITGEIST_TYPE_SUBJECT, NULL);
 
-    g_variant_iter_loop (subject_data, "s", &str);
+    g_variant_iter_next (subject_data, "s", &str);
     zeitgeist_subject_set_uri (subject, str[0] == '\0' ? NULL : str);
+    g_free (str);
 
-    g_variant_iter_loop (subject_data, "s", &str);
+    g_variant_iter_next (subject_data, "s", &str);
     zeitgeist_subject_set_interpretation (subject, str[0] == '\0' ? NULL : str);
+    g_free (str);
 
-    g_variant_iter_loop (subject_data, "s", &str);
+    g_variant_iter_next (subject_data, "s", &str);
     zeitgeist_subject_set_manifestation (subject, str[0] == '\0' ? NULL : str);
+    g_free (str);
 
-    g_variant_iter_loop (subject_data, "s", &str);
+    g_variant_iter_next (subject_data, "s", &str);
     zeitgeist_subject_set_origin (subject, str[0] == '\0' ? NULL : str);
+    g_free (str);
 
-    g_variant_iter_loop (subject_data, "s", &str);
+    g_variant_iter_next (subject_data, "s", &str);
     zeitgeist_subject_set_mimetype (subject, str[0] == '\0' ? NULL : str);
+    g_free (str);
 
-    g_variant_iter_loop (subject_data, "s", &str);
+    g_variant_iter_next (subject_data, "s", &str);
     zeitgeist_subject_set_text (subject, str[0] == '\0' ? NULL : str);
+    g_free (str);
 
-    g_variant_iter_loop (subject_data, "s", &str);
+    g_variant_iter_next (subject_data, "s", &str);
     zeitgeist_subject_set_storage (subject, str[0] == '\0' ? NULL : str);
+    g_free (str);
 
     zeitgeist_event_add_subject (result, subject);
   }
@@ -895,7 +907,8 @@ zeitgeist_events_from_variant (GVariant *events)
   for (i = 0; i < n_events; i++)
     {
       vevent = g_variant_get_child_value (events, i);
-      event = zeitgeist_event_new_from_variant (vevent); // vevent freed
+      event = zeitgeist_event_new_from_variant (vevent);
+      g_variant_unref (vevent);
       g_ptr_array_add (result, event);
     }
 
