@@ -381,9 +381,10 @@ zeitgeist_index_search_finish (ZeitgeistIndex      *self,
   /* Unpack return value from wrapper struct */
   vevents = g_variant_get_child_value (val, 0);
   vnum_hits = g_variant_get_child_value (val, 1);
-  events = zeitgeist_events_from_variant (vevents); // owns ref
+  events = zeitgeist_events_from_variant (vevents);
   num_hits = g_variant_get_uint32 (vnum_hits);
   g_variant_unref (val);
+  g_variant_unref (vevents);
   g_variant_unref (vnum_hits);
   return _zeitgeist_simple_result_set_new (events, num_hits);
 }
