@@ -482,6 +482,8 @@ zeitgeist_log_insert_events_finish (ZeitgeistLog        *self,
   event_ids = g_array_sized_new (FALSE, FALSE, sizeof (guint32), n_ids);
   g_array_append_vals (event_ids, raw_ids, n_ids);
 
+  g_variant_unref (_val);
+
   return event_ids;
 }
 
@@ -574,6 +576,8 @@ zeitgeist_log_find_events_finish (ZeitgeistLog        *self,
   g_variant_unref (val);
 
   events = zeitgeist_events_from_variant (_val);
+  g_variant_unref (_val);
+
   return _zeitgeist_simple_result_set_new (events, events->len);
 }
 
@@ -655,6 +659,8 @@ zeitgeist_log_find_event_ids_finish (ZeitgeistLog        *self,
   event_ids = g_array_sized_new (FALSE, FALSE, sizeof (guint32), n_ids);
   g_array_append_vals (event_ids, raw_ids, n_ids);
 
+  g_variant_unref (_val);
+
   return event_ids;
 }
 
@@ -718,6 +724,8 @@ zeitgeist_log_get_events_finish (ZeitgeistLog        *self,
   g_variant_unref (val);
 
   events = zeitgeist_events_from_variant (_val);
+  g_variant_unref (_val);
+
   return _zeitgeist_simple_result_set_new (events, events->len);
 }                          
 
@@ -1105,6 +1113,8 @@ monitor_handle_method_call (GDBusConnection       *connection,
       g_signal_emit_by_name (mon, "events-inserted", time_range, events);
       g_object_unref (time_range);
       g_object_unref (events);
+      g_variant_unref (vtime_range);
+      g_variant_unref (vevents);
       g_dbus_method_invocation_return_value (invocation, g_variant_new ("()"));
     }
   else if (g_strcmp0 (method_name, "NotifyDelete") == 0)
@@ -1118,6 +1128,7 @@ monitor_handle_method_call (GDBusConnection       *connection,
       g_array_append_vals (event_ids, raw_ids, n_ids);
       g_signal_emit_by_name (mon, "events-deleted", time_range, event_ids);
       g_object_unref (time_range);
+      g_variant_unref (vtime_range);
       g_variant_unref (vids);
       g_array_unref (event_ids);
       g_dbus_method_invocation_return_value (invocation, g_variant_new ("()"));
